198c9b8daecc44fbda6a6494c566c723920f030a
lrnassar
  Wed Mar 11 18:25:21 2026 -0700
Fixing a few hundred clear typos with the help of Claude. Some are less important in code comments, but majority of them are in user-facing places. I manually approved 60%+ of the changes and didn't see any that were an incorrect suggestion, at worst it was potentially uncessesary, like a code comment having cant instead of can't. No RM.

diff --git src/utils/tabFmt/tabFmt.c src/utils/tabFmt/tabFmt.c
index f7c3a488a24..57bf4e10e05 100644
--- src/utils/tabFmt/tabFmt.c
+++ src/utils/tabFmt/tabFmt.c
@@ -1,25 +1,25 @@
 /* tabFmt - Format a tab-seperated file for human readability. */
 #include "common.h"
 #include "linefile.h"
 #include "options.h"
 
 void usage()
 /* Explain usage and exit. */
 {
 errAbort(
-  "tabFmt - Format a tab-seperated file for human readability\n"
+  "tabFmt - Format a tab-separated file for human readability\n"
   "Usage:\n"
   "   tabFmt [options] inFile [outFile]\n"
   "\n"
@@ -1,25 +1,25 @@
-/* tabFmt - Format a tab-seperated file for human readability. */
+/* tabFmt - Format a tab-separated file for human readability. */
 #include "common.h"
 #include "linefile.h"
   "Options:\n"
     "  -right - right-justify\n"
     "  -numRight - right-justify numeric appearing columns (text header allowed)\n"
     "  -passNoTab - pass through lines with no tabs without including them in the\n"
     "   formatting\n"
     "  -h,-help - help\n"
   );
 }
 
 /* Command line validation table. */
 static struct optionSpec optionSpecs[] = {
     {"right", OPTION_BOOLEAN},